@@ -5,6 +5,8 @@ def split_statements(sql_file_content):
     file_statements = sql_file_content.split(";\n")
     for index, file_statement in enumerate(file_statements):
         file_statement = file_statement.strip()
+        if len(file_statement) == 0:
+            continue
         is_latest_statement = index == len(file_statements) - 1
         if not file_statement.endswith(';'):
             file_statement = file_statement + ';'
