@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 import json
 
-from sqlformat.models.SQLStatement import SQLStatement
+from sqlformat.helper import sql_helper
 
 
 class StorageStrategyTemplate(ABC):
@@ -26,9 +26,11 @@ class StorageStrategyTemplate(ABC):
         statements = []
         for sql_file in sql_procedure:
             sql_file_content = self._read_sql(sql_file["file"])
-            statements += split_statements(sql_file_content)
+            statements += sql_helper.split_statements(sql_file_content)
         return statements
 
+
+
     @abstractmethod
     def _read_procedure(self, procedure_path):
         pass
@@ -38,15 +40,3 @@ class StorageStrategyTemplate(ABC):
         pass
 
 
-def split_statements(sql_file_content):
-    statements = []
-    file_statements = sql_file_content.split(";\n")
-    for index, file_statement in enumerate(file_statements):
-        file_statement = file_statement.strip()
-        is_latest_statement = index == len(file_statements) - 1
-        if not file_statement.endswith(';'):
-            file_statement = file_statement + ';'
-        statement = SQLStatement(file_statement)
-        statement.is_latest_statement = is_latest_statement
-        statements.append(statement)
-    return statements
